You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ws.apache.org by ve...@apache.org on 2017/02/02 23:35:57 UTC

svn commit: r1781486 - in /webservices/axiom/trunk: aspects/om-aspects/src/main/java/org/apache/axiom/om/impl/common/factory/ axiom-api/src/main/java/org/apache/axiom/attachments/ axiom-api/src/main/java/org/apache/axiom/mime/ axiom-api/src/main/java/o...

Author: veithen
Date: Thu Feb  2 23:35:56 2017
New Revision: 1781486

URL: http://svn.apache.org/viewvc?rev=1781486&view=rev
Log:
Rename MIMEMessage to MultipartBody.

Added:
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/MultipartBodyAdapter.java
      - copied, changed from r1781485, webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/MIMEMessageAdapter.java
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/MultipartBody.java
      - copied, changed from r1781485, webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/MIMEMessage.java
Removed:
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/MIMEMessageAdapter.java
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/MIMEMessage.java
Modified:
    webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/om/impl/common/factory/AbstractOMMetaFactory.java
    webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/om/impl/common/factory/BuilderSpec.java
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/AttachmentSet.java
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/Attachments.java
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/AttachmentsDelegate.java
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/IncomingAttachmentStreams.java
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/PartImpl.java
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/PartIterator.java
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/om/OMMetaFactorySPI.java
    webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/om/OMXMLBuilderFactory.java

Modified: webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/om/impl/common/factory/AbstractOMMetaFactory.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/om/impl/common/factory/AbstractOMMetaFactory.java?rev=1781486&r1=1781485&r2=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/om/impl/common/factory/AbstractOMMetaFactory.java (original)
+++ webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/om/impl/common/factory/AbstractOMMetaFactory.java Thu Feb  2 23:35:56 2017
@@ -26,7 +26,7 @@ import javax.xml.transform.Source;
 import javax.xml.transform.sax.SAXSource;
 
 import org.apache.axiom.core.NodeFactory;
-import org.apache.axiom.mime.MIMEMessage;
+import org.apache.axiom.mime.MultipartBody;
 import org.apache.axiom.om.OMAttachmentAccessor;
 import org.apache.axiom.om.OMMetaFactory;
 import org.apache.axiom.om.OMMetaFactorySPI;
@@ -73,7 +73,7 @@ public abstract class AbstractOMMetaFact
     }
 
     @Override
-    public OMXMLParserWrapper createOMBuilder(StAXParserConfiguration configuration, MIMEMessage message) {
+    public OMXMLParserWrapper createOMBuilder(StAXParserConfiguration configuration, MultipartBody message) {
         return OM.createBuilder(nodeFactory, BuilderSpec.from(configuration, message));
     }
 
@@ -98,7 +98,7 @@ public abstract class AbstractOMMetaFact
     }
 
     @Override
-    public SOAPModelBuilder createSOAPModelBuilder(MIMEMessage message) {
+    public SOAPModelBuilder createSOAPModelBuilder(MultipartBody message) {
         return SOAP.createBuilder(nodeFactory, BuilderSpec.from(StAXParserConfiguration.SOAP, message));
     }
 

Modified: webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/om/impl/common/factory/BuilderSpec.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/om/impl/common/factory/BuilderSpec.java?rev=1781486&r1=1781485&r2=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/om/impl/common/factory/BuilderSpec.java (original)
+++ webservices/axiom/trunk/aspects/om-aspects/src/main/java/org/apache/axiom/om/impl/common/factory/BuilderSpec.java Thu Feb  2 23:35:56 2017
@@ -38,7 +38,7 @@ import org.apache.axiom.core.stream.Name
 import org.apache.axiom.core.stream.XmlInput;
 import org.apache.axiom.core.stream.dom.DOMInput;
 import org.apache.axiom.core.stream.sax.SAXInput;
-import org.apache.axiom.mime.MIMEMessage;
+import org.apache.axiom.mime.MultipartBody;
 import org.apache.axiom.mime.Part;
 import org.apache.axiom.om.OMAttachmentAccessor;
 import org.apache.axiom.om.OMException;
@@ -186,7 +186,7 @@ final class BuilderSpec {
         return new BuilderSpec(new FilteredXmlInput(new SAXInput(source, expandEntityReferences), NamespaceRepairingFilter.DEFAULT), null);
     }
 
-    static BuilderSpec from(StAXParserConfiguration configuration, final MIMEMessage message) {
+    static BuilderSpec from(StAXParserConfiguration configuration, final MultipartBody message) {
         Part rootPart = message.getRootPart();
         InputSource is;
         try {

Modified: webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/AttachmentSet.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/AttachmentSet.java?rev=1781486&r1=1781485&r2=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/AttachmentSet.java (original)
+++ webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/AttachmentSet.java Thu Feb  2 23:35:56 2017
@@ -28,7 +28,7 @@ import java.util.Set;
 import javax.activation.DataHandler;
 
 import org.apache.axiom.mime.ContentType;
-import org.apache.axiom.mime.MIMEMessage;
+import org.apache.axiom.mime.MultipartBody;
 import org.apache.axiom.om.OMException;
 
 /**
@@ -96,8 +96,8 @@ class AttachmentSet extends AttachmentsD
     }
 
     @Override
-    MIMEMessage getMIMEMessage() {
+    MultipartBody getMultipartBody() {
         throw new IllegalStateException(
-                "The attachments map was created programatically. MIMEMessage is not available.");
+                "The attachments map was created programatically. MultipartBody is not available.");
     }
 }

Modified: webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/Attachments.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/Attachments.java?rev=1781486&r1=1781485&r2=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/Attachments.java (original)
+++ webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/Attachments.java Thu Feb  2 23:35:56 2017
@@ -28,7 +28,7 @@ import org.apache.axiom.blob.WritableBlo
 import org.apache.axiom.blob.WritableBlobFactory;
 import org.apache.axiom.ext.activation.SizeAwareDataSource;
 import org.apache.axiom.mime.ContentType;
-import org.apache.axiom.mime.MIMEMessage;
+import org.apache.axiom.mime.MultipartBody;
 import org.apache.axiom.om.OMAttachmentAccessor;
 import org.apache.axiom.om.OMException;
 import org.apache.axiom.om.impl.MTOMConstants;
@@ -119,7 +119,7 @@ public class Attachments implements OMAt
             attachmentBlobFactory = MemoryBlob.FACTORY;
         }
         
-        delegate = new MIMEMessageAdapter(inStream, contentTypeString, attachmentBlobFactory,
+        delegate = new MultipartBodyAdapter(inStream, contentTypeString, attachmentBlobFactory,
                 contentLength);
     }
 
@@ -406,7 +406,7 @@ public class Attachments implements OMAt
         throw new UnsupportedOperationException();
     }
 
-    public MIMEMessage getMIMEMessage() {
-        return delegate.getMIMEMessage();
+    public MultipartBody getMultipartBody() {
+        return delegate.getMultipartBody();
     }
 }
\ No newline at end of file

Modified: webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/AttachmentsDelegate.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/AttachmentsDelegate.java?rev=1781486&r1=1781485&r2=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/AttachmentsDelegate.java (original)
+++ webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/AttachmentsDelegate.java Thu Feb  2 23:35:56 2017
@@ -26,7 +26,7 @@ import java.util.Set;
 import javax.activation.DataHandler;
 
 import org.apache.axiom.mime.ContentType;
-import org.apache.axiom.mime.MIMEMessage;
+import org.apache.axiom.mime.MultipartBody;
 import org.apache.axiom.om.OMException;
 
 /**
@@ -60,5 +60,5 @@ abstract class AttachmentsDelegate {
     abstract Set<String> getContentIDs(boolean fetchAll);
     abstract Map<String,DataHandler> getMap();
     abstract long getContentLength() throws IOException;
-    abstract MIMEMessage getMIMEMessage();
+    abstract MultipartBody getMultipartBody();
 }

Modified: webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/IncomingAttachmentStreams.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/IncomingAttachmentStreams.java?rev=1781486&r1=1781485&r2=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/IncomingAttachmentStreams.java (original)
+++ webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/IncomingAttachmentStreams.java Thu Feb  2 23:35:56 2017
@@ -23,7 +23,7 @@ import java.io.IOException;
 import java.util.Iterator;
 
 import org.apache.axiom.mime.Header;
-import org.apache.axiom.mime.MIMEMessage;
+import org.apache.axiom.mime.MultipartBody;
 import org.apache.axiom.mime.Part;
 import org.apache.axiom.om.OMException;
 
@@ -42,7 +42,7 @@ public final class IncomingAttachmentStr
      */
     private boolean readyToGetNextStream = true;
 
-    IncomingAttachmentStreams(MIMEMessage message) {
+    IncomingAttachmentStreams(MultipartBody message) {
         rootPart = message.getRootPart();
         partIterator = message.iterator();
     }

Copied: webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/MultipartBodyAdapter.java (from r1781485, webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/MIMEMessageAdapter.java)
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/MultipartBodyAdapter.java?p2=webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/MultipartBodyAdapter.java&p1=webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/MIMEMessageAdapter.java&r1=1781485&r2=1781486&rev=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/MIMEMessageAdapter.java (original)
+++ webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/attachments/MultipartBodyAdapter.java Thu Feb  2 23:35:56 2017
@@ -32,18 +32,18 @@ import org.apache.axiom.blob.WritableBlo
 import org.apache.axiom.mime.ContentType;
 import org.apache.axiom.mime.DataHandlerFactory;
 import org.apache.axiom.mime.Header;
-import org.apache.axiom.mime.MIMEMessage;
-import org.apache.axiom.mime.MIMEMessage.PartCreationListener;
+import org.apache.axiom.mime.MultipartBody;
+import org.apache.axiom.mime.MultipartBody.PartCreationListener;
 import org.apache.axiom.mime.Part;
 import org.apache.axiom.om.OMException;
 import org.apache.axiom.util.UIDGenerator;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
-final class MIMEMessageAdapter extends AttachmentsDelegate implements PartCreationListener {
-    private static final Log log = LogFactory.getLog(MIMEMessageAdapter.class);
+final class MultipartBodyAdapter extends AttachmentsDelegate implements PartCreationListener {
+    private static final Log log = LogFactory.getLog(MultipartBodyAdapter.class);
 
-    private final MIMEMessage message;
+    private final MultipartBody message;
     private final Map<String,DataHandler> map = new LinkedHashMap<String,DataHandler>();
     private final int contentLength;
     private final CountingInputStream filterIS;
@@ -55,7 +55,7 @@ final class MIMEMessageAdapter extends A
     /** Container to hold streams for direct access */
     private IncomingAttachmentStreams streams;
 
-    MIMEMessageAdapter(InputStream inStream, String contentTypeString,
+    MultipartBodyAdapter(InputStream inStream, String contentTypeString,
             WritableBlobFactory<?> attachmentBlobFactory, int contentLength) {
         this.contentLength = contentLength;
         if (log.isDebugEnabled()) {
@@ -70,7 +70,7 @@ final class MIMEMessageAdapter extends A
             filterIS = null;
         }
 
-        this.message = MIMEMessage.newBuilder()
+        this.message = MultipartBody.newBuilder()
                 .setInputStream(inStream)
                 .setContentType(contentTypeString)
                 .setAttachmentBlobFactory(attachmentBlobFactory)
@@ -222,7 +222,7 @@ final class MIMEMessageAdapter extends A
     }
 
     @Override
-    MIMEMessage getMIMEMessage() {
+    MultipartBody getMultipartBody() {
         return message;
     }
 }

Copied: webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/MultipartBody.java (from r1781485, webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/MIMEMessage.java)
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/MultipartBody.java?p2=webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/MultipartBody.java&p1=webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/MIMEMessage.java&r1=1781485&r2=1781486&rev=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/MIMEMessage.java (original)
+++ webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/MultipartBody.java Thu Feb  2 23:35:56 2017
@@ -49,7 +49,7 @@ import org.apache.james.mime4j.stream.Re
  * <p>
  * Instances of this class are created using a fluent builder; see {@link #newBuilder()}.
  */
-public final class MIMEMessage implements Iterable<Part> {
+public final class MultipartBody implements Iterable<Part> {
     public interface PartCreationListener {
         void partCreated(Part part);
     }
@@ -97,14 +97,14 @@ public final class MIMEMessage implement
             return this;
         }
 
-        public MIMEMessage build() {
+        public MultipartBody build() {
             if (inputStream == null) {
                 throw new IllegalArgumentException("inputStream is mandatory");
             }
             if (contentType == null) {
                 throw new IllegalArgumentException("contentType is mandatory");
             }
-            return new MIMEMessage(
+            return new MultipartBody(
                     inputStream,
                     contentType,
                     attachmentBlobFactory == null ? MemoryBlob.FACTORY : attachmentBlobFactory,
@@ -113,7 +113,7 @@ public final class MIMEMessage implement
         }
     }
 
-    private static final Log log = LogFactory.getLog(MIMEMessage.class);
+    private static final Log log = LogFactory.getLog(MultipartBody.class);
     
     /** <code>ContentType</code> of the MIME message */
     private final ContentType contentType;
@@ -137,7 +137,7 @@ public final class MIMEMessage implement
     private final DataHandlerFactory dataHandlerFactory;
     private final PartCreationListener partCreationListener;
     
-    MIMEMessage(InputStream inStream, ContentType contentType,
+    MultipartBody(InputStream inStream, ContentType contentType,
             WritableBlobFactory<?> attachmentBlobFactory,
             DataHandlerFactory dataHandlerFactory,
             PartCreationListener partCreationListener) {

Modified: webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/PartImpl.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/PartImpl.java?rev=1781486&r1=1781485&r2=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/PartImpl.java (original)
+++ webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/PartImpl.java Thu Feb  2 23:35:56 2017
@@ -67,7 +67,7 @@ final class PartImpl implements Part {
 
     private static final Log log = LogFactory.getLog(PartImpl.class);
     
-    private final MIMEMessage message;
+    private final MultipartBody message;
     private final WritableBlobFactory<?> blobFactory;
     
     private final String contentID;
@@ -93,7 +93,7 @@ final class PartImpl implements Part {
     
     private PartImpl nextPart;
     
-    PartImpl(MIMEMessage message, WritableBlobFactory<?> blobFactory, String contentID, List<Header> headers, MimeTokenStream parser) {
+    PartImpl(MultipartBody message, WritableBlobFactory<?> blobFactory, String contentID, List<Header> headers, MimeTokenStream parser) {
         this.message = message;
         this.blobFactory = blobFactory;
         this.contentID = contentID;

Modified: webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/PartIterator.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/PartIterator.java?rev=1781486&r1=1781485&r2=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/PartIterator.java (original)
+++ webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/mime/PartIterator.java Thu Feb  2 23:35:56 2017
@@ -22,11 +22,11 @@ import java.util.Iterator;
 import java.util.NoSuchElementException;
 
 final class PartIterator implements Iterator<Part> {
-    private final MIMEMessage message;
+    private final MultipartBody message;
     private PartImpl part;
     private boolean hasNextCalled;
 
-    PartIterator(MIMEMessage message) {
+    PartIterator(MultipartBody message) {
         this.message = message;
     }
 

Modified: webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/om/OMMetaFactorySPI.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/om/OMMetaFactorySPI.java?rev=1781486&r1=1781485&r2=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/om/OMMetaFactorySPI.java (original)
+++ webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/om/OMMetaFactorySPI.java Thu Feb  2 23:35:56 2017
@@ -23,7 +23,7 @@ import javax.xml.stream.XMLStreamReader;
 import javax.xml.transform.Source;
 import javax.xml.transform.sax.SAXSource;
 
-import org.apache.axiom.mime.MIMEMessage;
+import org.apache.axiom.mime.MultipartBody;
 import org.apache.axiom.om.util.StAXParserConfiguration;
 import org.apache.axiom.soap.SOAPFactory;
 import org.apache.axiom.soap.SOAPModelBuilder;
@@ -120,7 +120,7 @@ public interface OMMetaFactorySPI extend
      *            the MIME message
      * @return the builder
      */
-    OMXMLParserWrapper createOMBuilder(StAXParserConfiguration configuration, MIMEMessage message);
+    OMXMLParserWrapper createOMBuilder(StAXParserConfiguration configuration, MultipartBody message);
     
     OMXMLParserWrapper createOMBuilder(Source rootPart, OMAttachmentAccessor attachmentAccessor);
     
@@ -164,7 +164,7 @@ public interface OMMetaFactorySPI extend
      *            the MIME message
      * @return the builder
      */
-    SOAPModelBuilder createSOAPModelBuilder(MIMEMessage message);
+    SOAPModelBuilder createSOAPModelBuilder(MultipartBody message);
     
     SOAPModelBuilder createSOAPModelBuilder(Source rootPart, OMAttachmentAccessor attachmentAccessor);
 }

Modified: webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/om/OMXMLBuilderFactory.java
URL: http://svn.apache.org/viewvc/webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/om/OMXMLBuilderFactory.java?rev=1781486&r1=1781485&r2=1781486&view=diff
==============================================================================
--- webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/om/OMXMLBuilderFactory.java (original)
+++ webservices/axiom/trunk/axiom-api/src/main/java/org/apache/axiom/om/OMXMLBuilderFactory.java Thu Feb  2 23:35:56 2017
@@ -29,7 +29,7 @@ import javax.xml.transform.sax.SAXSource
 
 import org.apache.axiom.attachments.Attachments;
 import org.apache.axiom.ext.stax.datahandler.DataHandlerReader;
-import org.apache.axiom.mime.MIMEMessage;
+import org.apache.axiom.mime.MultipartBody;
 import org.apache.axiom.om.util.StAXParserConfiguration;
 import org.apache.axiom.soap.SOAP12Constants;
 import org.apache.axiom.soap.SOAPFactory;
@@ -438,14 +438,14 @@ public class OMXMLBuilderFactory {
      *             if an error occurs while processing the content type information from the
      *             {@link Attachments} object
      * 
-     * @deprecated Use {@link #createOMBuilder(StAXParserConfiguration, MIMEMessage)} instead.
+     * @deprecated Use {@link #createOMBuilder(StAXParserConfiguration, MultipartBody)} instead.
      */
     public static OMXMLParserWrapper createOMBuilder(StAXParserConfiguration configuration, Attachments attachments) {
-        return createOMBuilder(configuration, attachments.getMIMEMessage());
+        return createOMBuilder(configuration, attachments.getMultipartBody());
     }
     
     /**
      * Create an XOP aware model builder from the provided {@link MIMEMessage} object and with a
      * given parser configuration.
      * 
      * @param configuration
@@ -455,9 +455,9 @@ public class OMXMLBuilderFactory {
      * @return the builder
      * @throws OMException
      *             if an error occurs while processing the content type information from the
-     *             {@link MIMEMessage} object
+     *             {@link MultipartBody} object
      */
-    public static OMXMLParserWrapper createOMBuilder(StAXParserConfiguration configuration, MIMEMessage message) {
+    public static OMXMLParserWrapper createOMBuilder(StAXParserConfiguration configuration, MultipartBody message) {
         return createOMBuilder(OMAbstractFactory.getMetaFactory().getOMFactory(), configuration, message);
     }
     
@@ -476,16 +476,16 @@ public class OMXMLBuilderFactory {
      *             if an error occurs while processing the content type information from the
      *             {@link Attachments} object
      * 
-     * @deprecated Use {{@link #createOMBuilder(OMFactory, StAXParserConfiguration, MIMEMessage)}
+     * @deprecated Use {{@link #createOMBuilder(OMFactory, StAXParserConfiguration, MultipartBody)}
      *             instead.
      */
     public static OMXMLParserWrapper createOMBuilder(OMFactory omFactory,
             StAXParserConfiguration configuration, Attachments attachments) {
-        return createOMBuilder(omFactory, configuration, attachments.getMIMEMessage());
+        return createOMBuilder(omFactory, configuration, attachments.getMultipartBody());
     }
 
     /**
      * Create an XOP aware model builder from the provided {@link MIMEMessage} object using a
      * specified object model factory and with a given parser configuration.
      * 
      * @param omFactory
@@ -497,10 +497,10 @@ public class OMXMLBuilderFactory {
      * @return the builder
      * @throws OMException
      *             if an error occurs while processing the content type information from the
-     *             {@link MIMEMessage} object
+     *             {@link MultipartBody} object
      */
     public static OMXMLParserWrapper createOMBuilder(OMFactory omFactory,
-            StAXParserConfiguration configuration, MIMEMessage message) {
+            StAXParserConfiguration configuration, MultipartBody message) {
         return ((OMMetaFactorySPI)omFactory.getMetaFactory()).createOMBuilder(configuration, message);
     }
     
@@ -652,16 +652,16 @@ public class OMXMLBuilderFactory {
      *             if an error occurs while processing the content type information from the
      *             {@link Attachments} object
      * 
-     * @deprecated Use {@link #createSOAPModelBuilder(MIMEMessage)} instead
+     * @deprecated Use {@link #createSOAPModelBuilder(MultipartBody)} instead
      */
     public static SOAPModelBuilder createSOAPModelBuilder(Attachments attachments) {
-        return createSOAPModelBuilder(attachments.getMIMEMessage());
+        return createSOAPModelBuilder(attachments.getMultipartBody());
     }
     
     /**
      * Create an MTOM aware model builder from the provided {@link MIMEMessage} object. The method
      * will determine the SOAP version based on the content type information from the
      * {@link MIMEMessage} object. It will configure the underlying parser as specified by
      * {@link StAXParserConfiguration#SOAP}.
      * 
      * @param message
@@ -669,9 +669,9 @@ public class OMXMLBuilderFactory {
      * @return the builder
      * @throws OMException
      *             if an error occurs while processing the content type information from the
-     *             {@link MIMEMessage} object
+     *             {@link MultipartBody} object
      */
-    public static SOAPModelBuilder createSOAPModelBuilder(MIMEMessage message) {
+    public static SOAPModelBuilder createSOAPModelBuilder(MultipartBody message) {
         return createSOAPModelBuilder(OMAbstractFactory.getMetaFactory(), message);
     }
     
@@ -690,17 +690,17 @@ public class OMXMLBuilderFactory {
      *             if an error occurs while processing the content type information from the
      *             {@link Attachments} object
      * 
-     * @deprecated Use {@link #createSOAPModelBuilder(OMMetaFactory, MIMEMessage)} instead.
+     * @deprecated Use {@link #createSOAPModelBuilder(OMMetaFactory, MultipartBody)} instead.
      */
     public static SOAPModelBuilder createSOAPModelBuilder(OMMetaFactory metaFactory,
             Attachments attachments) {
-        return createSOAPModelBuilder(metaFactory, attachments.getMIMEMessage());
+        return createSOAPModelBuilder(metaFactory, attachments.getMultipartBody());
     }
 
     /**
      * Create an MTOM aware model builder from the provided {@link MIMEMessage} object using a
      * particular Axiom implementation. The method will determine the SOAP version based on the
      * content type information from the {@link MIMEMessage} object. It will configure the
      * underlying parser as specified by {@link StAXParserConfiguration#SOAP}.
      * 
      * @param metaFactory
@@ -710,10 +710,10 @@ public class OMXMLBuilderFactory {
      * @return the builder
      * @throws OMException
      *             if an error occurs while processing the content type information from the
-     *             {@link MIMEMessage} object
+     *             {@link MultipartBody} object
      */
     public static SOAPModelBuilder createSOAPModelBuilder(OMMetaFactory metaFactory,
-            MIMEMessage message) {
+            MultipartBody message) {
         String type = message.getRootPart().getContentType().getParameter("type");
         SOAPFactory soapFactory;
         if ("text/xml".equalsIgnoreCase(type)) {
@@ -438,14 +438,14 @@ public class OMXMLBuilderFactory {
     
     /**
-     * Create an XOP aware model builder from the provided {@link MIMEMessage} object and with a
+     * Create an XOP aware model builder from the provided {@link MultipartBody} object and with a
      * given parser configuration.
      * 
@@ -476,16 +476,16 @@ public class OMXMLBuilderFactory {
 
     /**
-     * Create an XOP aware model builder from the provided {@link MIMEMessage} object using a
+     * Create an XOP aware model builder from the provided {@link MultipartBody} object using a
      * specified object model factory and with a given parser configuration.
      * 
@@ -652,16 +652,16 @@ public class OMXMLBuilderFactory {
     
     /**
-     * Create an MTOM aware model builder from the provided {@link MIMEMessage} object. The method
+     * Create an MTOM aware model builder from the provided {@link MultipartBody} object. The method
      * will determine the SOAP version based on the content type information from the
@@ -652,16 +652,16 @@ public class OMXMLBuilderFactory {
      * will determine the SOAP version based on the content type information from the
-     * {@link MIMEMessage} object. It will configure the underlying parser as specified by
+     * {@link MultipartBody} object. It will configure the underlying parser as specified by
      * {@link StAXParserConfiguration#SOAP}.
      * 
@@ -690,17 +690,17 @@ public class OMXMLBuilderFactory {
 
     /**
-     * Create an MTOM aware model builder from the provided {@link MIMEMessage} object using a
+     * Create an MTOM aware model builder from the provided {@link MultipartBody} object using a
      * particular Axiom implementation. The method will determine the SOAP version based on the
@@ -690,17 +690,17 @@ public class OMXMLBuilderFactory {
      * particular Axiom implementation. The method will determine the SOAP version based on the
-     * content type information from the {@link MIMEMessage} object. It will configure the
+     * content type information from the {@link MultipartBody} object. It will configure the
      * underlying parser as specified by {@link StAXParserConfiguration#SOAP}.
      * 